@@ -35,16 +35,16 @@ import Framework
 
 class RateLimiting(Framework.TestCase):
     def testRateLimiting(self):
-        self.assertEqual(self.g.rate_limiting, (5000, 5000))
+        self.assertEqual(self.g.rate_limiting, (4929, 5000))
         self.g.get_user("jacquev6")
-        self.assertEqual(self.g.rate_limiting, (4999, 5000))
-        self.assertEqual(self.g.rate_limiting_resettime, 1375802816)
+        self.assertEqual(self.g.rate_limiting, (4928, 5000))
+        self.assertEqual(self.g.rate_limiting_resettime, 1536123356)
 
     def testResetTime(self):
-        self.assertEqual(self.g.rate_limiting_resettime, 1375802816)
+        self.assertEqual(self.g.rate_limiting_resettime, 1536123356)
 
     def testGetRateLimit(self):
         rateLimit = self.g.get_rate_limit()
-        self.assertEqual(rateLimit.rate.limit, 5000)
-        self.assertEqual(rateLimit.rate.remaining, 5000)
-        self.assertEqual(rateLimit.rate.reset, datetime.datetime(2013, 9, 6, 10, 29, 57))
+        self.assertEqual(rateLimit.core.limit, 5000)
+        self.assertEqual(rateLimit.core.remaining, 4929)
+        self.assertEqual(rateLimit.core.reset, datetime.datetime(2018, 9, 5, 4, 55, 56))
